@@ -1,5 +1,7 @@
 import logging
 
+from ..common.manifest_dataset import ManifestDataset
+
 from .dataset import Dataset
 
 logger = logging.getLogger(__name__)
@@ -10,7 +12,7 @@ class TorchDataset(Dataset):
     Dataset class used for pytorch training
     """
 
-    def __init__(self, manifest_dataset, transform=None):
+    def __init__(self, manifest_dataset: ManifestDataset, transform=None):
         Dataset.__init__(self, transform)
         self.dataset = manifest_dataset
 
